/// <reference types="react" />
import type { AnyAction } from 'redux';
import type { Document } from 'mongodb';
import type { SortDirection, IndexesThunkAction } from '.';
import type { SearchIndex } from 'mongodb-data-service';
export type SearchSortColumn = keyof typeof sortColumnToProps;
declare const sortColumnToProps: {
    readonly 'Name and Fields': "name";
    readonly Status: "status";
};
export declare enum SearchIndexesStatuses {
    NOT_AVAILABLE = "NOT_AVAILABLE",
    PENDING = "PENDING",
    READY = "READY",
    REFRESHING = "REFRESHING",
    ERROR = "ERROR"
}
export type SearchIndexesStatus = keyof typeof SearchIndexesStatuses;
export declare enum ActionTypes {
    SetStatus = "indexes/search-indexes/SetStatus",
    OpenCreateSearchIndexModal = "indexes/search-indexes/OpenCreateSearchIndexModal",
    CreateSearchIndexStarted = "indexes/search-indexes/CreateSearchIndexStarted",
    CreateSearchIndexFailed = "indexes/search-indexes/CreateSearchIndexFailed",
    CreateSearchIndexSucceeded = "indexes/search-indexes/CreateSearchIndexSucceed",
    CreateSearchIndexCancelled = "indexes/search-indexes/CreateSearchIndexCancelled",
    SetIsRefreshing = "indexes/search-indexes/SetIsRefreshing",
    SetSearchIndexes = "indexes/search-indexes/SetSearchIndexes",
    SearchIndexesSorted = "indexes/search-indexes/SearchIndexesSorted",
    SetError = "indexes/search-indexes/SetError"
}
type SetIsRefreshingAction = {
    type: ActionTypes.SetIsRefreshing;
};
type OpenCreateSearchIndexModalAction = {
    type: ActionTypes.OpenCreateSearchIndexModal;
};
type CreateSearchIndexStartedAction = {
    type: ActionTypes.CreateSearchIndexStarted;
};
type CreateSearchIndexFailedAction = {
    type: ActionTypes.CreateSearchIndexFailed;
    error: string;
};
type CreateSearchIndexSucceededAction = {
    type: ActionTypes.CreateSearchIndexSucceeded;
};
type CreateSearchIndexCancelledAction = {
    type: ActionTypes.CreateSearchIndexCancelled;
};
type CreateSearchIndexState = {
    isModalOpen: boolean;
    isBusy: boolean;
};
export type State = {
    status: SearchIndexesStatus;
    createIndex: CreateSearchIndexState;
    error?: string;
    indexes: SearchIndex[];
    sortOrder: SortDirection;
    sortColumn: SearchSortColumn;
};
type SetSearchIndexesAction = {
    type: ActionTypes.SetSearchIndexes;
    indexes: SearchIndex[];
};
type SearchIndexesSortedAction = {
    type: ActionTypes.SearchIndexesSorted;
    indexes: SearchIndex[];
    sortOrder: SortDirection;
    sortColumn: SearchSortColumn;
};
type SetErrorAction = {
    type: ActionTypes.SetError;
    error: string | undefined;
};
type SearchIndexesActions = SetIsRefreshingAction | SetSearchIndexesAction | SearchIndexesSortedAction | SetErrorAction;
export declare const INITIAL_STATE: State;
export default function reducer(state: State | undefined, action: AnyAction): State;
export declare const openModalForCreation: () => OpenCreateSearchIndexModalAction;
export declare const closeModal: () => CreateSearchIndexCancelledAction;
export declare const createIndexStarted: () => CreateSearchIndexStartedAction;
export declare const createIndexFailed: (error: string) => CreateSearchIndexFailedAction;
export declare const createIndexSucceeded: () => CreateSearchIndexSucceededAction;
export declare const saveIndex: (indexName: string, indexDefinition: Document) => IndexesThunkAction<Promise<void>>;
export declare const fetchSearchIndexes: () => IndexesThunkAction<Promise<void>, SearchIndexesActions>;
export declare const refreshSearchIndexes: () => IndexesThunkAction<void>;
export declare const sortSearchIndexes: (column: SearchSortColumn, direction: SortDirection) => IndexesThunkAction<void, SearchIndexesSortedAction>;
export declare const showConfirmation: (props: {
    title: string;
    description: import("react").ReactNode;
    buttonText?: string | undefined;
    variant?: import("@mongodb-js/compass-components").ConfirmationModalVariant | undefined;
    requiredInputText?: string | undefined;
}) => Promise<boolean>;
export declare const dropSearchIndex: (name: string) => IndexesThunkAction<Promise<void>>;
export {};
//# sourceMappingURL=search-indexes.d.ts.map